==> ckeditor5_youtube-1.0.0.tar.gz: ckeditor5_youtube/src/Plugin/CKEditor5Plugin/Youtube.php <==
<?php

declare(strict_types=1);

namespace Drupal\ckeditor5_youtube\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\ckeditor5\Plugin\CKEditor5PluginElementsSubsetInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\EditorInterface;

/**
 * Defines a Drupal YouTube plugin for CKEditor5.
 */
class Youtube extends CKEditor5PluginDefault implements CKEditor5PluginElementsSubsetInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritDoc}
   */
  public function getElementsSubset(): array {
    $requiredAttributes = [
      'src',
    ];
    $allowedAttributes = array_merge($requiredAttributes, $this->configuration['enabled_optional_attributes']);
    $allowedAttributes = array_combine($allowedAttributes, $allowedAttributes);
    return [
      '<iframe>',
      sprintf("<iframe %s>", implode(' ', $allowedAttributes)),
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $checkboxOptions = [];
    foreach ($this->getOptionalAttributes() as $attribute) {
      $label = $attribute;
      if (in_array($attribute, $this->getDeprecatedOptionalAttributes())) {
        $label .= ' ' . $this->t('(deprecated)');
      }
      $checkboxOptions[$attribute] = $label;
    }
    $form['enabled_optional_attributes'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Allowed optional attributes'),
      '#options' => $checkboxOptions,
      '#default_value' => $this->configuration['enabled_optional_attributes'],
      '#description' => $this->t("Beyond src, which attributes to allow on YouTube embeds. Refer to <a href=':url'>YouTube Player iframe API</a> for a description of these attributes.", [
        ':url' => 'https://developers.google.com/youtube/player_parameters',
      ]),
    ];
    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritDoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $submittedAttributes = array_filter(array_values($form_state->getValue('enabled_optional_attributes')));
    $this->configuration['enabled_optional_attributes'] = $submittedAttributes;
  }

  /**
   * {@inheritDoc}
   */
  public function defaultConfiguration() {
    return [
      'enabled_optional_attributes' => array_diff($this->getOptionalAttributes(), $this->getDeprecatedOptionalAttributes()),
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    return [
      'youtube' => [
        'enabled_optional_attributes' => $this->configuration['enabled_optional_attributes'],
      ],
    ];
  }

  /**
   * Get a list of available attributes to allow for a YouTube embed.
   *
   * @return array
   *   The attributes.
   */
  private function getOptionalAttributes(): array {
    return [
      'align',
      'frameborder',
      'height',
      'width',
      'longdesc',
      'name',
      'scrolling',
      'tabindex',
      'title',
      'allowfullscreen',
      'referrerpolicy',
      'allow',
    ];
  }

  /**
   * List of attributes that shouldn't be used anymore.
   *
   * @return string[]
   *   The list of deprecated attributes.
   */
  private function getDeprecatedOptionalAttributes(): array {
    return [
      'align',
      'frameborder',
      'longdesc',
      'scrolling',
    ];
  }

}

==> ckeditor5_youtube-1.0.3.tar.gz: ckeditor5_youtube/src/Plugin/CKEditor5Plugin/Youtube.php <==
<?php

declare(strict_types=1);

namespace Drupal\ckeditor5_youtube\Plugin\CKEditor5Plugin;

use Drupal\Core\Form\FormStateInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\ckeditor5\Plugin\CKEditor5PluginElementsSubsetInterface;
use Drupal\editor\EditorInterface;

/**
 * Defines a Drupal YouTube plugin for CKEditor5.
 */
class Youtube extends CKEditor5PluginDefault implements CKEditor5PluginElementsSubsetInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritDoc}
   */
  public function getElementsSubset(): array {
    $requiredAttributes = [
      'src',
    ];
    $allowedAttributes = array_merge($requiredAttributes, $this->configuration['enabled_optional_attributes']);
    $allowedAttributes = array_combine($allowedAttributes, $allowedAttributes);
    return [
      '<iframe>',
      sprintf("<iframe %s>", implode(' ', $allowedAttributes)),
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $checkboxOptions = [];
    foreach ($this->getOptionalAttributes() as $attribute) {
      $label = $attribute;
      if (in_array($attribute, $this->getDeprecatedOptionalAttributes())) {
        $label .= ' ' . $this->t('(deprecated)');
      }
      $checkboxOptions[$attribute] = $label;
    }
    $form['enabled_optional_attributes'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Allowed optional attributes'),
      '#options' => $checkboxOptions,
      '#default_value' => $this->configuration['enabled_optional_attributes'],
      '#description' => $this->t("Beyond src, which attributes to allow on YouTube embeds. Refer to <a href=':url'>YouTube Player iframe API</a> for a description of these attributes.", [
        ':url' => 'https://developers.google.com/youtube/player_parameters',
      ]),
    ];
    return $form;
  }

  /**
   * Get a list of available attributes to allow for a YouTube embed.
   *
   * @return array
   *   The attributes.
   */
  private function getOptionalAttributes(): array {
    return [
      'align',
      'frameborder',
      'height',
      'width',
      'longdesc',
      'name',
      'scrolling',
      'tabindex',
      'title',
      'allowfullscreen',
      'referrerpolicy',
      'allow',
    ];
  }

  /**
   * List of attributes that shouldn't be used anymore.
   *
   * @return string[]
   *   The list of deprecated attributes.
   */
  private function getDeprecatedOptionalAttributes(): array {
    return [
      'align',
      'frameborder',
      'longdesc',
      'scrolling',
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritDoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $submittedAttributes = array_filter(array_values($form_state->getValue('enabled_optional_attributes')));
    $this->configuration['enabled_optional_attributes'] = $submittedAttributes;
  }

  /**
   * {@inheritDoc}
   */
  public function defaultConfiguration() {
    return [
      'enabled_optional_attributes' => array_diff($this->getOptionalAttributes(), $this->getDeprecatedOptionalAttributes()),
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    return [
      'youtube' => [
        'enabled_optional_attributes' => $this->configuration['enabled_optional_attributes'],
      ],
    ];
  }

}
